ActionException class

Custom exception for action-specific errors

Implemented types
Implementers

Constructors

ActionException(String message, {String? code, Map<String, dynamic>? metadata})
const

Properties

code String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited