ExampleQuestion class

Represents a suggested question shown to users before they start chatting.

Constructors

ExampleQuestion({required String question, ExampleQuestionConfig? config})
const

Properties

config ExampleQuestionConfig?
final
hashCode int
The hash code for this object.
no setterinherited
question String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited