AgentCollaboration class
Collaboration between multiple agents
Constructors
-
AgentCollaboration({required String id, required List<
String> participantAgentIds, required String coordinatorAgentId, required String topic, CollaborationStatus status = CollaborationStatus.active, List<AgentResponse> responses = const [], required DateTime startedAt, DateTime? completedAt}) -
const
Properties
- completedAt → DateTime?
-
final
- coordinatorAgentId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
participantAgentIds
→ List<
String> -
final
-
responses
→ List<
AgentResponse> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime
-
final
- status → CollaborationStatus
-
final
- topic → String
-
final
Methods
-
copyWith(
{String? id, List< String> ? participantAgentIds, String? coordinatorAgentId, String? topic, CollaborationStatus? status, List<AgentResponse> ? responses, DateTime? startedAt, DateTime? completedAt}) → AgentCollaboration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited