AgentResponse class
Response from an agent
Constructors
-
AgentResponse({required String id, required String requestId, required String agentId, required String content, required AgentResponseType type, double confidence = 1.0, Map<
String, dynamic> metadata = const {}, List<AgentAction> ? suggestedActions, required DateTime timestamp}) -
const
Properties
- agentId → String
-
final
- confidence → double
-
final
- content → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
metadata
→ Map<
String, dynamic> -
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
suggestedActions
→ List<
AgentAction> ? -
final
- timestamp → DateTime
-
final
- type → AgentResponseType
-
final
Methods
-
copyWith(
{String? id, String? requestId, String? agentId, String? content, AgentResponseType? type, double? confidence, Map< String, dynamic> ? metadata, List<AgentAction> ? suggestedActions, DateTime? timestamp}) → AgentResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited